@@ -4,5 +4,5 @@ class CurrentSquaredMixin(Quantity):
 
     quantity = 'currentsquared'
     quantity_label = 'Current^2'
-    units = 'A^2'
+    quantity_units = 'A^2'
     is_currentsquared = True
