@@ -1507,6 +1507,9 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
     def is_unchanging(self):
         """Returns True if expression does not have a domain variable (compare with `is_constant`)."""
 
+        if self.var is None:
+            return True
+        
         return self.var not in self.expr.free_symbols
     
     def evaluate(self, arg=None):
@@ -1799,7 +1802,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
         """Simplify terms in expression individually."""
 
         result = 0
-        for term in self.expr.expand().as_ordered_terms():
+        for term in self.expr.as_ordered_terms():
             result += symsimplify(term)
         return self.__class__(result, **self.assumptions)
 
@@ -1807,7 +1810,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
         """Simplify factors in expression individually."""
 
         result = 0
-        for factor in self.expr.factor().as_ordered_factors():
+        for factor in self.expr.as_ordered_factors():
             result *= symsimplify(factor)
         return self.__class__(result, **self.assumptions)
 
@@ -2488,16 +2491,20 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
         result = foo(coeffs)
         return self.__class__(result, **self.assumptions)
 
-    def change(self, expr, domain=None, units_scale=None, **assumptions):
+    def change(self, arg, domain=None, units_scale=None, **assumptions):
         """Change expression class."""
 
         if domain is None:
             domain = self.domain
 
+        if domain == 'constant':
+            # Allow changing of constants, e.g., V1 to 5 * t
+            domain = expr(arg).domain
+            
         quantity = self.quantity
 
         cls = self._class_by_quantity(quantity, domain)        
-        ret = cls(expr, **assumptions)
+        ret = cls(arg, **assumptions)
 
         if units_scale is not None:
             ret.units = self.units * units_scale
