@@ -2,7 +2,7 @@
 This module defines the components for modified nodal analysis.  The components
 are defined at the bottom of this file.
 
-Copyright 2015--2020 Michael Hayes, UCECE
+Copyright 2015--2021 Michael Hayes, UCECE
 
 """
 
@@ -43,6 +43,8 @@ class Cpt(ImmittanceMixin):
     directive = False
     flip_branch_current = False
     ignore = False
+    add_series = False
+    add_parallel = False    
     equipotential_nodes = ()
     
 
@@ -91,7 +93,9 @@ class Cpt(ImmittanceMixin):
             # Default value is the component name
             value = self.type + self.id
 
-            if self.type in ('V', 'I') and keyword[1] == '':
+            if False and self.type in ('V', 'I') and keyword[1] == '':
+                # This is too subtle and creates havoc with
+                # the expected behaviour of subs.
                 value = value[0].lower() + value[1:] + '(t)'
 
             args += (value, )
@@ -839,6 +843,7 @@ class RC(RLC):
 class C(RC):
 
     reactive = True
+    add_parallel = True
 
     @property
     def C(self):
@@ -885,7 +890,7 @@ class C(RC):
     def _ss_model(self):
         # Perhaps mangle name to ensure it does not conflict
         # with another voltage source?
-        return self._netmake_variant('V_', args=())
+        return self._netmake_variant('V_', args='v_%s(t)' % self.relname)        
         
     @property
     def V0(self):
@@ -1068,6 +1073,8 @@ class CCVS(DependentSource):
 
 class I(IndependentSource):
 
+    add_parallel = True    
+
     def _select(self, kind=None):
         """Select domain kind for component."""
         return self._netmake(args=self.cpt.Isc.netval(kind))
@@ -1091,7 +1098,7 @@ class I(IndependentSource):
             cct._Is[n2] -= I
 
     def _ss_model(self):
-        return self._netmake(args='%s(t)' % self.relname.lower)
+        return self._netmake(args='%s(t)' % self.relname.lower())
 
     def _s_model(self, var):
         return self._netmake(args=self.Isc.laplace()(var))
@@ -1145,6 +1152,7 @@ class L(RLC):
     
     need_branch_current = True
     reactive = True
+    add_series = True    
 
     def _r_model(self):
 
@@ -1249,6 +1257,8 @@ class P(O):
 
 class R(RC):
 
+    add_series = True    
+    
     def _r_model(self):    
         return self._copy()
 
@@ -1433,7 +1443,8 @@ class TR(Dummy):
 class V(IndependentSource):
 
     need_branch_current = True
-    flip_branch_current = True        
+    flip_branch_current = True
+    add_series = True
 
     def _select(self, kind=None):
         """Select domain kind for component."""
@@ -1497,12 +1508,14 @@ class Y(RC):
     """Admittance"""
 
     reactive = True
+    add_parallel = True
 
 
 class Z(RC):
     """Impedance"""
 
-    reactive = True    
+    reactive = True
+    add_series = True    
 
 
 classes = {}
@@ -1598,6 +1611,7 @@ defcpt('Upinverter', Logic, 'Inverter with power supplies')
 defcpt('Uinamp', Misc, 'Instrumentation amplifier')
 defcpt('Uisoamp', Misc, 'Isolated amplifier')
 defcpt('Udiffamp', Misc, 'Differential amplifier')
+defcpt('Udiffdriver', Misc, 'Differential driver')
 defcpt('Ufdopamp', Misc, 'Fully differential opamp ')
 defcpt('Uopamp', Misc, 'Opamp ')
 defcpt('Uregulator', Misc, 'Regulator ')
