@@ -1,7 +1,7 @@
 """This module provides the NetlistMixin class.  This is used for
 Netlist and SubNetlist.
 
-Copyright 2020 Michael Hayes, UCECE
+Copyright 2020-2021 Michael Hayes, UCECE
 
 """
 
@@ -115,6 +115,17 @@ class NetlistMixin(object):
 
         return '\n'.join([str(cpt) for cpt in self._elements.values()])
 
+    def has(self, cpt):
+        """Return True if cpt in elements."""
+
+        return cpt in self.elements
+    
+    @property
+    def is_connected(self):
+        """Return True if all components are connected."""
+
+        return self.cg.is_connected
+
     def _node_add(self, node, cpt):
 
         if node not in self.nodes:
@@ -585,14 +596,36 @@ class NetlistMixin(object):
         domain.   See also conductance, reactance, resistance."""
         return self.impedance(Np, Nm).B
         
-    def transfer(self, N1p, N1m, N2p, N2m):
+    def transfer(self, N1p, N1m, N2p=None, N2m=None):
         """Create s-domain voltage transfer function V2(s) / V1(s) where:
         V1 is V[N1p] - V[N1m]
         V2 is V[N2p] - V[N2m]
 
         Note, independent sources are killed and initial conditions
         are ignored.  Since the result is causal, the frequency response
-        can be found by substituting j * omega for s."""
+        can be found by substituting j * omega for s.
+
+        An alternative syntax is transfer(cpt1, cpt2)."""
+
+        if N2p is None and N2m is None:
+            try:
+                N1p = self.elements[N1p]
+            except:
+                pass
+            try:
+                N1m = self.elements[N1m]
+            except:
+                pass            
+            
+            if N1p not in self.elements.values():
+                raise ValueError('Unknown component %s' % N1p)
+            if N1m not in self.elements.values():
+                raise ValueError('Unknown component %s' % N1m)            
+            N2p, N2m = [n.name for n in N1m.nodes[0:2]]
+            N1p, N1m = [n.name for n in N1p.nodes[0:2]]
+            
+        elif N2p is None or N2m is None:
+            raise ValueError('Expecting transfer(cpt1, cpt2) or transfer(N1p, N1m, N2p, N2m)')
 
         N1p, N1m, N2p, N2m = self._check_nodes(N1p, N1m, N2p, N2m)
         
@@ -1024,16 +1057,16 @@ class NetlistMixin(object):
         return self._noisy(resistors)
 
     @property
-    def G(self):
-        """Generate graph for this netlist."""        
+    def cg(self):
+        """Generate graph for this netlist.   This is cached."""        
 
         from .circuitgraph import CircuitGraph
         
-        if hasattr(self, '_G'):
-            return self._G
+        if hasattr(self, '_cg'):
+            return self._cg
 
-        self._G = CircuitGraph(self)
-        return self._G
+        self._cg = CircuitGraph(self)
+        return self._cg
     
     def _potential_combine_names(self):
 
@@ -1047,18 +1080,22 @@ class NetlistMixin(object):
         """Return dict of subsets of component names where each subset has the
         same component type."""
 
+        aset = aset.copy()
+
         subsets = {}
         while aset != set():
             name = aset.pop()
+            cpt = self._elements[name]
             aset.add(name)
             
             subset = set()
             for name1 in aset:
-                if name[0] == name1[0]:
+                cpt1 = self._elements[name1]                
+                if cpt.type == cpt1.type:
                     subset.add(name1)
             aset -= subset
             if len(subset) > 1:
-                subsets[name[0]] = subset
+                subsets[cpt.type] = subset
         return subsets
 
     def _in_parallel_all(self):
@@ -1098,17 +1135,16 @@ class NetlistMixin(object):
         if isinstance(cpt, Cpt):
             cpt = cpt.name
 
-        return self.G.in_parallel(cpt)
+        return self.cg.in_parallel(cpt)
 
     def _in_series_names(self, cpt=None):
 
         if isinstance(cpt, Cpt):
             cpt = cpt.name
 
-        return self.G.in_series(cpt)
+        return self.cg.in_series(cpt)
         
     def in_parallel(self, cpt=None):
-
         """Return set of cpts in parallel with specified cpt.  If no cpt
         specified, return list of sets of parallel cpts."""
 
@@ -1121,7 +1157,7 @@ class NetlistMixin(object):
         return names
     
     def in_series(self, cpt=None):
-        """Return set of cpts in series with specified cpt.   If no cpt
+        """Return set of cpts in series with specified cpt.  If no cpt
         specified, return list of sets of series cpts."""
 
         if cpt is None:
@@ -1132,7 +1168,8 @@ class NetlistMixin(object):
             return set()
         return names
 
-    def _do_simplify(self, string, subset, net, explain=False, add=False, series=False):
+    def _do_simplify_combine(self, string, subset, net, explain=False, add=False,
+                     series=False):
 
         if explain:
             print(string % subset)
@@ -1215,7 +1252,7 @@ class NetlistMixin(object):
             newelements[v.name] = v
         self._elements = newelements
     
-    def _simplify_series(self, cptnames=None, explain=False):
+    def _simplify_combine_series(self, cptnames=None, explain=False):
 
         net = self.copy()
         changed = False
@@ -1226,13 +1263,13 @@ class NetlistMixin(object):
                 if k == 'I':
                     print('Netlist has current sources in series: %s' % subset)
                 elif k in ('R', 'L', 'V', 'Z'):
-                    if k == 'L' and  not self._check_ic(subset):
+                    if k == 'L' and not self._check_ic(subset):
                         continue
-                    changed |= self._do_simplify('Can add in series: %s',
-                                                 subset, net, explain, True, True)
+                    changed |= self._do_simplify_combine('Can add in series: %s',
+                                                         subset, net, explain, True, True)
                 elif k in ('C', 'Y'):
-                    changed |= self._do_simplify('Can combine in series: %s',
-                                                 subset, net, explain, False, True)
+                    changed |= self._do_simplify_combine('Can combine in series: %s',
+                                                         subset, net, explain, False, True)
                 else:
                     raise RuntimeError('Internal error')
 
@@ -1241,7 +1278,7 @@ class NetlistMixin(object):
                 
         return net, changed
 
-    def _simplify_parallel(self, cptnames=None, explain=False):
+    def _simplify_combine_parallel(self, cptnames=None, explain=False):
 
         net = self.copy()
         changed = False        
@@ -1250,15 +1287,15 @@ class NetlistMixin(object):
             subsets = net._find_combine_subsets(aset)
             for k, subset in subsets.items():
                 if k == 'V':
-                    print('Netlist has voltage sources in parallel: %s'%  subset)
+                    print('Netlist has voltage sources in parallel: %s'% subset)
                 elif k in ('R', 'L', 'Z'):
-                    changed |= self._do_simplify('Can combine in parallel: %s',
-                                                 subset, net, explain, False, False)
+                    changed |= self._do_simplify_combine('Can combine in parallel: %s',
+                                                         subset, net, explain, False, False)
                 elif k in ('C', 'Y', 'I'):
                     if k == 'C' and  not self._check_ic(subset):
                         continue                    
-                    changed |= self._do_simplify('Can add in parallel: %s',
-                                                 subset, net, explain, True, False)
+                    changed |= self._do_simplify_combine('Can add in parallel: %s',
+                                                         subset, net, explain, True, False)
                 else:
                     raise RuntimeError('Internal error')
                 
@@ -1268,6 +1305,58 @@ class NetlistMixin(object):
                 
         return net, changed
 
+    def _simplify_redundant_series(self, cptnames=None, explain=False):
+
+        net = self.copy()
+        changed = False
+
+        for aset in net.in_series():        
+            Iname = None
+            for name in aset:
+                cpt = self._elements[name]                
+                if cpt.type == 'I':
+                    Iname = name
+                    break
+            if Iname is not None:
+                for name in aset:
+                    cpt = self._elements[name]                    
+                    if cpt.type != 'I':
+                        print('Warning, have redundant %s in series with %s' % (name, Iname))
+                
+        return net, False        
+
+    def _simplify_redundant_parallel(self, cptnames=None, explain=False):
+
+        net = self.copy()
+        changed = False
+
+        for aset in net.in_parallel():
+            Vname = None
+            for name in aset:
+                cpt = self._elements[name]
+                if cpt.type == 'V':
+                    Vname = name
+                    break
+            if Vname is not None:
+                for name in aset:
+                    cpt = self._elements[name]
+                    if cpt.type != 'V':
+                        print('Warning, have redundant %s in parallel with %s' % (name, Vname))
+
+        return net, False
+
+    def _simplify_series(self, cptnames=None, explain=False):
+
+        net, changed = self._simplify_redundant_series(cptnames, explain)        
+        net, changed2 = net._simplify_combine_series(cptnames, explain)
+        return net, changed or changed2
+
+    def _simplify_parallel(self, cptnames=None, explain=False):
+
+        net, changed = self._simplify_redundant_parallel(cptnames, explain)
+        net, changed2 = net._simplify_combine_parallel(cptnames, explain)
+        return net, changed or changed2    
+
     def simplify_series(self, cptnames=None, explain=False, modify=True):
 
         net, changed = self._simplify_series(cptnames, explain)
@@ -1301,6 +1390,11 @@ class NetlistMixin(object):
             
         return net
 
+    def check(self):
+        """Check if network contains a loop of voltage sources or a cut set of current sources."""
+
+        return self.simplify(explain=True, modify=False)
+    
     def twoport(self, N1p, N1m, N2p, N2m, model='B'):
         """Create s-domain twoport model for two-port defined by nodes N1p, N1m, N2p, and N2m, where:
         I1 is the current flowing into N1p and out of N1m
@@ -1376,8 +1470,36 @@ class NetlistMixin(object):
         self._ss = StateSpace(self)
         return self._ss
 
+    def replace(self, oldname, newname):
+        """Replace component.
+        
+        For example,
+        b = a.replace('C', 'W')
+        c = a.replace('C1', 'C1 1 2')
+        """        
+
+        new = self._new()
+
+        newparts = newname.split(' ')
+
+        for cpt in self._elements.values():
+            net = cpt._copy()            
+            if cpt.name == oldname:
+                if len(newparts) == 1:
+                    # Just replace name of component
+                    parts = net.split(' ')
+                    parts[0] = newname
+                    net = ' '.join(parts)
+                else:
+                    # Replace with new net
+                    net = newname
+            new._add(net)
+        return new
+
     def subs(self, subs_dict):
-        """Substitute values using dictionary of subsitutions."""        
+        """Substitute values using dictionary of substitutions.
+        
+        For example, b = a.subs({'R1': 1e3, 'R2': 9e3})"""
 
         new = self._new()
 
@@ -1776,4 +1898,3 @@ class NetlistMixin(object):
     def Iname(self, name):
         return Iname(name, self.kind)    
 
-                
