@@ -12,28 +12,9 @@ This module performs schematic drawing using circuitikz from a netlist.
 >>> sch.add('W 0.2 0.2; right')
 >>> sch.draw()
 
-Copyright 2014--2020 Michael Hayes, UCECE
+Copyright 2014--2021 Michael Hayes, UCECE
 """
 
-# Components are positioned using two graphs; one graph for
-# the x direction and the other for the y direction. 
-#
-# There is naming confusion.  We have network nodes (electrical
-# nodes) and nodes in the graph used for component placement.
-# Let's call the latter gnodes.  The names of these gnodes are a
-# tuple of the common network nodes.
-#
-# x and y component positioning are performed independently.  Let's
-# consider the x or horizontal positioning.  There are three stages:
-#   1. Component nodes that share a y position are linked; this can
-#      occur, for example, for a vertically oriented component.
-#      This helps to reduce the size of the graph.
-#   2. The x positions of the components are used to determine the
-#      graph edges.
-#   3. The longest path through the graph is found and the x positions
-#      of the nodes are assigned based on the distance along the
-#      longest path.
-
 # Strings starting with ;; are schematic options.  They are parsed in
 # netfile.py and added to the opts attribute of the netlist.  They get
 # passed to the draw method of the Schematic class.
@@ -44,12 +25,11 @@ from .latex import latex_format_label, latex_format_node_label
 from .expr import Expr
 from . import schemcpts
 import sympy as sym
-from .schemgraph import Graph
 from .schemmisc import Pos
+from .schemplacer import schemplacer
 from .opts import Opts
 from .netfile import NetfileMixin
-from .system import run_latex, convert_pdf_png, convert_pdf_svg
-from .system import tmpfilename, circuitikz_version, latex_cleanup
+from .system import LatexRunner, PDFConverter, tmpfilename
 from os import path, remove
 from collections import OrderedDict
 import math
@@ -314,7 +294,7 @@ class Schematic(NetfileMixin):
         self.scale = 1.0
         self.dummy_node = 0
         self.context = None
-        self.debug = False
+        self.debug = 0
 
         if filename is not None:
             self.netfile_add(filename)
@@ -351,12 +331,6 @@ class Schematic(NetfileMixin):
 
         return '\n'.join([elt.__str__() for elt in self.elements.values()])
 
-    def _invalidate(self):
-
-        for attr in ('xgraph', 'ygraph'):
-            if hasattr(self, attr):
-                delattr(self, attr)
-
     def _node_add(self, nodename, elt, auxiliary=False):
 
         if nodename not in self.nodes:
@@ -486,8 +460,6 @@ class Schematic(NetfileMixin):
         if cpt.opts_string != '':
             self.hints = True
 
-        self._invalidate()
-
         if cpt.name in self.elements:
             print('Overriding component %s' % cpt.name)
             # Need to search lists and update component.
@@ -501,60 +473,6 @@ class Schematic(NetfileMixin):
         for node in cpt.required_node_names:
             self._node_add(node, cpt, auxiliary=False)
 
-    def make_graphs(self, debug=None):
-
-        if debug is None:
-            debug = self.debug
-        
-        # The x and y positions of a component node are determined
-        # independently.  The principle is that each component has a
-        # minimum size (usually 1 but changeable with the size option)
-        # but its wires can be stretched.
-
-        # When solving the x position, first nodes that must be
-        # vertically aligned (with the up or down option) are combined
-        # into a set.  Then the left and right options are used to
-        # form a graph.  This graph is traversed to find the longest
-        # path and in the process each node gets assigned the longest
-        # distance from the root of the graph.  To centre components,
-        # a reverse graph is created and the distances are averaged.
-
-        self.xgraph = Graph('horizontal', self.nodes, debug)
-        self.ygraph = Graph('vertical', self.nodes, debug)
-
-        # Use components in orthogonal directions as constraints.  The
-        # nodes of orthogonal components get combined into a
-        # common node.
-        for m, elt in enumerate(self.elements.values()):
-
-            if elt.offset != 0:
-                raise ValueError('offset field should be removed')
-            if elt.directive or elt.ignore:
-                continue
-            
-            elt.xlink(self.xgraph)
-            elt.ylink(self.ygraph)
-
-        # Now form forward and reverse directed graph using components
-        # in the desired directions.
-        # Note, this must be done after the linking step.
-        for m, elt in enumerate(self.elements.values()):
-            if elt.directive or elt.ignore:
-                continue            
-            elt.xplace(self.xgraph)
-            elt.yplace(self.ygraph)
-            
-    def _positions_calculate(self):
-
-        self.make_graphs()
-
-        xpos, self.width = self.xgraph.analyse()
-        ypos, self.height = self.ygraph.analyse()
-
-        scale = self.node_spacing
-        for n, node in self.nodes.items():
-            node.pos = Pos(xpos[n] * scale, ypos[n] * scale)
-
     def _setup(self):
         # This is called before node positions are assigned.
 
@@ -567,13 +485,24 @@ class Schematic(NetfileMixin):
             if node.cptname is not None and not node.implicit:
                 raise ValueError('Unreferenced pin connection %s for %s' % (node.name, node.elt_list))
 
+    def make_graphs(self, debug=0):
+
+        placer = schemplacer(self.elements, self.nodes, 'graph', debug)
+        placer._make_graphs()
+        return placer.xgraph, placer.ygraph
+
+    def _positions_calculate(self, method='graph', debug=False):
+
+        placer = schemplacer(self.elements, self.nodes, method, debug)
+        self.width, self.height = placer.solve(self.node_spacing)        
+    
     def _tikz_draw(self, style_args='', **kwargs):
 
-        self.debug = kwargs.pop('debug', False)
+        method = kwargs.pop('method', 'graph')
         
         self._setup()
-        
-        self._positions_calculate()
+
+        self._positions_calculate(method, self.debug)
 
         # Note, scale does not scale the font size.
         opts = ['scale=%.2f' % self.scale,
@@ -643,6 +572,7 @@ class Schematic(NetfileMixin):
 
         root, ext = path.splitext(filename)
 
+        self.debug = kwargs.pop('debug', 0)
         style = kwargs.pop('style', 'american')
         self.dpi = float(kwargs.pop('dpi', 150))        
         self.cpt_size = float(kwargs.pop('cpt_size', 1.2))
@@ -662,7 +592,9 @@ class Schematic(NetfileMixin):
         # For debugging when do not want to write to file
         nosave = kwargs.pop('nosave', False)
 
-        self.circuitikz_date, self.circuitikz_version = circuitikz_version()
+        latexrunner = LatexRunner(self.debug & 2)
+        
+        self.circuitikz_date, self.circuitikz_version = latexrunner.circuitikz_version()
         if self.circuitikz_date is None:
             raise RuntimeError('circuitikz is not installed')
 
@@ -671,7 +603,7 @@ class Schematic(NetfileMixin):
         if nosave:
             return
 
-        if self.debug:
+        if self.debug & 1:
             print('circuitikz version %s (%s)' % (self.circuitikz_version,
                                                   self.circuitikz_date))
             print('width=%d, height=%d, dpi=%d, cpt_size=%.2f, node_spacing=%.2f, scale=%.2f'
@@ -680,8 +612,6 @@ class Schematic(NetfileMixin):
             print('Nodes:')
             for node in self.nodes.values():
                 node.debug()
-            # print(self.xgraph.cnodes)
-            # print(self.ygraph.cnodes)
 
         if ext in ('.pytex', '.schtex', '.pgf'):
             open(filename, 'w').write(content)
@@ -691,10 +621,9 @@ class Schematic(NetfileMixin):
         template = ('\\documentclass[a4paper]{standalone}\n'
                     '\\usepackage{amsmath}\n'
                     '\\usepackage{circuitikz}\n'
-                    '\\usetikzlibrary{fit, shapes, arrows}\n'
+                    '\\usetikzlibrary{fit, shapes, arrows, patterns, decorations.text, decorations.markings}\n'
                     '\\begin{document}\n%s\\end{document}')
         content = template % content
-
         tex_filename = filename.replace(ext, '.tex')
         open(tex_filename, 'w').write(content)
 
@@ -702,9 +631,9 @@ class Schematic(NetfileMixin):
             return
 
         pdf_filename = tex_filename.replace('.tex', '.pdf')
-        run_latex(tex_filename)
-        if not self.debug:
-            latex_cleanup(tex_filename, pdf_filename)
+        latexrunner.run(tex_filename)
+        if not (self.debug & 1):
+            latexrunner.cleanup(tex_filename, pdf_filename)
 
         if not path.exists(pdf_filename):
             raise RuntimeError('Could not generate %s with pdflatex' % 
@@ -714,14 +643,16 @@ class Schematic(NetfileMixin):
             return
 
         if ext == '.svg':
-            convert_pdf_svg(pdf_filename, root + '.svg')
-            if not self.debug:
+            pdfconverter = PDFConverter(self.debug & 2)
+            pdfconverter.to_svg(pdf_filename, root + '.svg')
+            if not (self.debug & 1):
                 remove(pdf_filename)
             return
 
         if ext == '.png':
-            convert_pdf_png(pdf_filename, root + '.png', self.dpi)
-            if not self.debug:
+            pdfconverter = PDFConverter(self.debug & 2)
+            pdfconverter.to_png(pdf_filename, root + '.png', self.dpi)
+            if not (self.debug & 1):
                 remove(pdf_filename)
             return
 
@@ -755,7 +686,7 @@ class Schematic(NetfileMixin):
            cpt_size: size of a component, default 1.5
            dpi: dots per inch for png files
            help_lines: distance between lines in grid, default 0.0 (disabled)
-           debug: True to display debug information
+           debug: Non-zero to display debug information
         """
 
         # None means don't care, so remove.
@@ -829,8 +760,8 @@ class Schematic(NetfileMixin):
 
             from IPython.display import Image, display_png
 
-            pngfilename = tmpfilename('.png')
-            self.tikz_draw(pngfilename, **kwargs)
+            png_filename = tmpfilename('.png')
+            self.tikz_draw(png_filename, **kwargs)
             
             # Create and display PNG image object.
             # There are two problems:
@@ -838,10 +769,12 @@ class Schematic(NetfileMixin):
             #    when the ipynb file is loaded.
             # 2. The image metadata (width, height) is not stored
             #    when the ipynb file is written non-interactively.
-            width, height = png_image_size(pngfilename)
+            width, height = png_image_size(png_filename)
             # width, height specify the image dimension in pixels
-            display_png(Image(filename=pngfilename,
+            display_png(Image(filename=png_filename,
                               width=width, height=height))
+            if not (self.debug & 1):
+                remove(png_filename)            
             return
 
         if filename is None:
@@ -849,9 +782,11 @@ class Schematic(NetfileMixin):
             # Thicken up lines to reduce aliasing causing them to
             # disappear, especially when using pdftoppm.
             self.tikz_draw(filename=filename, 
-                           options='bipoles/thickness=2',
+                           options='/tikz/circuitikz/bipoles/thickness=2',
                            **kwargs)
             display_matplotlib(filename, self.dpi)
+            if not (self.debug & 1):
+                remove(filename)            
             return
 
         self.tikz_draw(filename=filename, **kwargs)
