@@ -48,7 +48,15 @@ class StateSpace(object):
     """This converts a circuit to state-space representation.
 
     It can take a long time for a symbolic circuit with many reactive
-    components."""
+    components.
+
+    This does not (yet) look for degenerate circuits.  These are
+    circuits with a loop consisting only of voltage sources and/or
+    capacitors, or cut sets consisting only of current sources and/or
+    inductors.  One hack is to call simplify() first to remove series
+    inductors and parallel capacitors.
+
+    """
 
     def __init__(self, cct, node_voltages=True, branch_currents=False):
 
