@@ -308,6 +308,15 @@ class LcapyTester(unittest.TestCase):
         a3 = s.subs({s: omega})
         self.assertEqual(a1, a3, "Substitution fail with dict.")
 
+    def test_subs_const(self):
+        """Lcapy: check subs of a constant
+
+        """
+        a = expr('V1')
+        b = expr(5 * t)
+        c = a.subs({'V1':b})
+
+        self.assertEqual(c, b, "Substitution for constant fail.")
 
     def test_types(self):
         """Lcapy: check types
@@ -421,7 +430,8 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.has_symbol('b'), False, "has_symbol(b)")
         #self.assertEqual(a.symbols[1].is_positive, True, "a is positive")
         self.assertEqual(a.is_constant, False, "is_constant")                
-
+        self.assertEqual(a.is_unchanging, False, "is_unchanging")
+        
         a = expr('3')
         self.assertEqual(a.is_constant, True, "3 is_constant")
         self.assertEqual(a.is_unchanging, True, "3 is_unchanging")
